@@ -1,7 +1,6 @@
 from .helper import timestamp_to_datetime
 import six
 
-
 class ApiModel(object):
 
     @classmethod
@@ -78,13 +77,19 @@ class Media(ApiModel):
         new_media.user = User.object_from_dictionary(entry['user'])
 
         new_media.images = {}
-        for version, version_info in six.iteritems(entry['images']):
+        for version, version_info in six.iteritems(entry.get('images')):
             new_media.images[version] = Image.object_from_dictionary(version_info)
 
         if new_media.type == 'video':
             new_media.videos = {}
-            for version, version_info in six.iteritems(entry['videos']):
-                new_media.videos[version] = Video.object_from_dictionary(version_info)
+            if entry.get('videos', False):
+                for version, version_info in six.iteritems(entry['videos']):
+                    new_media.videos[version] = Video.object_from_dictionary(version_info)
+
+            ## Sometimes images return with type: 'videos'
+            elif entry.get('images', False):
+                for version, version_info in six.iteritems(entry['images']):
+                    new_media.images[version] = Image.object_from_dictionary(version_info)
 
         if 'user_has_liked' in entry:
             new_media.user_has_liked = entry['user_has_liked']
